# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class SearchRequestKnn(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'field': 'str',
        'query_vector': '[float]',
        'k': 'int',
        'filter': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'doc_id': 'int'
    }

    attribute_map = {
        'field': 'field',
        'query_vector': 'query_vector',
        'k': 'k',
        'filter': 'filter',
        'doc_id': 'doc_id'
    }

    def __init__(self, field="", query_vector=None, k=None, filter={}, doc_id=None, local_vars_configuration=None):  # noqa: E501
        """SearchRequestKnn - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._field = None
        self._query_vector = None
        self._k = None
        self._filter = None
        self._doc_id = None
        self.discriminator = None

        self.field = field
        self.query_vector = query_vector
        self.k = k
        self.filter = filter
        self.doc_id = doc_id

    @property
    def field(self):
        """Gets the field of this SearchRequestKnn.  # noqa: E501


        :return: The field of this SearchRequestKnn.  # noqa: E501
        :rtype: str
        """
        return self._field
    @field.setter
    def field(self, field):
        """Sets the field of this SearchRequestKnn.


        :param field: The field of this SearchRequestKnn.  # noqa: E501
        :type field: str
        """
        if self.local_vars_configuration.client_side_validation and field is None:  # noqa: E501
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field
        

    @property
    def query_vector(self):
        """Gets the query_vector of this SearchRequestKnn.  # noqa: E501


        :return: The query_vector of this SearchRequestKnn.  # noqa: E501
        :rtype: [float]
        """
        return self._query_vector
    @query_vector.setter
    def query_vector(self, query_vector):
        """Sets the query_vector of this SearchRequestKnn.


        :param query_vector: The query_vector of this SearchRequestKnn.  # noqa: E501
        :type query_vector: [float]
        """
        if self.local_vars_configuration.client_side_validation and query_vector is None:  # noqa: E501
            raise ValueError("Invalid value for `query_vector`, must not be `None`")  # noqa: E501

        self._query_vector = query_vector
        

    @property
    def k(self):
        """Gets the k of this SearchRequestKnn.  # noqa: E501


        :return: The k of this SearchRequestKnn.  # noqa: E501
        :rtype: int
        """
        return self._k
    @k.setter
    def k(self, k):
        """Sets the k of this SearchRequestKnn.


        :param k: The k of this SearchRequestKnn.  # noqa: E501
        :type k: int
        """
        if self.local_vars_configuration.client_side_validation and k is None:  # noqa: E501
            raise ValueError("Invalid value for `k`, must not be `None`")  # noqa: E501

        self._k = k
        

    @property
    def filter(self):
        """Gets the filter of this SearchRequestKnn.  # noqa: E501


        :return: The filter of this SearchRequestKnn.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._filter
    @filter.setter
    def filter(self, filter):
        """Sets the filter of this SearchRequestKnn.


        :param filter: The filter of this SearchRequestKnn.  # noqa: E501
        :type filter: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        if self.local_vars_configuration.client_side_validation and filter is None:  # noqa: E501
            raise ValueError("Invalid value for `filter`, must not be `None`")  # noqa: E501

        self._filter = filter
        

    @property
    def doc_id(self):
        """Gets the doc_id of this SearchRequestKnn.  # noqa: E501


        :return: The doc_id of this SearchRequestKnn.  # noqa: E501
        :rtype: int
        """
        return self._doc_id
    @doc_id.setter
    def doc_id(self, doc_id):
        """Sets the doc_id of this SearchRequestKnn.


        :param doc_id: The doc_id of this SearchRequestKnn.  # noqa: E501
        :type doc_id: int
        """
        if self.local_vars_configuration.client_side_validation and doc_id is None:  # noqa: E501
            raise ValueError("Invalid value for `doc_id`, must not be `None`")  # noqa: E501

        self._doc_id = doc_id
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequestKnn):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchRequestKnn):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class BulkResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'errors': 'bool',
        'error': 'str'
    }

    attribute_map = {
        'items': 'items',
        'errors': 'errors',
        'error': 'error'
    }

    def __init__(self, items=None, errors=None, error=None, local_vars_configuration=None):  # noqa: E501
        """BulkResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items = None
        self._errors = None
        self._error = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if errors is not None:
            self.errors = errors
        if error is not None:
            self.error = error

    @property
    def items(self):
        """Gets the items of this BulkResponse.  # noqa: E501


        :return: The items of this BulkResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._items
    @items.setter
    def items(self, items):
        """Sets the items of this BulkResponse.


        :param items: The items of this BulkResponse.  # noqa: E501
        :type items: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._items = items
        

    @property
    def errors(self):
        """Gets the errors of this BulkResponse.  # noqa: E501


        :return: The errors of this BulkResponse.  # noqa: E501
        :rtype: bool
        """
        return self._errors
    @errors.setter
    def errors(self, errors):
        """Sets the errors of this BulkResponse.


        :param errors: The errors of this BulkResponse.  # noqa: E501
        :type errors: bool
        """

        self._errors = errors
        

    @property
    def error(self):
        """Gets the error of this BulkResponse.  # noqa: E501


        :return: The error of this BulkResponse.  # noqa: E501
        :rtype: str
        """
        return self._error
    @error.setter
    def error(self, error):
        """Sets the error of this BulkResponse.


        :param error: The error of this BulkResponse.  # noqa: E501
        :type error: str
        """

        self._error = error
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BulkResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class SearchResponseHits(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max_score': 'int',
        'total': 'int',
        'total_relation': 'str',
        'hits': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]'
    }

    attribute_map = {
        'max_score': 'max_score',
        'total': 'total',
        'total_relation': 'total_relation',
        'hits': 'hits'
    }

    def __init__(self, max_score=None, total=None, total_relation=None, hits=None, local_vars_configuration=None):  # noqa: E501
        """SearchResponseHits - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._max_score = None
        self._total = None
        self._total_relation = None
        self._hits = None
        self.discriminator = None

        if max_score is not None:
            self.max_score = max_score
        if total is not None:
            self.total = total
        if total_relation is not None:
            self.total_relation = total_relation
        if hits is not None:
            self.hits = hits

    @property
    def max_score(self):
        """Gets the max_score of this SearchResponseHits.  # noqa: E501


        :return: The max_score of this SearchResponseHits.  # noqa: E501
        :rtype: int
        """
        return self._max_score
    @max_score.setter
    def max_score(self, max_score):
        """Sets the max_score of this SearchResponseHits.


        :param max_score: The max_score of this SearchResponseHits.  # noqa: E501
        :type max_score: int
        """

        self._max_score = max_score
        

    @property
    def total(self):
        """Gets the total of this SearchResponseHits.  # noqa: E501


        :return: The total of this SearchResponseHits.  # noqa: E501
        :rtype: int
        """
        return self._total
    @total.setter
    def total(self, total):
        """Sets the total of this SearchResponseHits.


        :param total: The total of this SearchResponseHits.  # noqa: E501
        :type total: int
        """

        self._total = total
        

    @property
    def total_relation(self):
        """Gets the total_relation of this SearchResponseHits.  # noqa: E501


        :return: The total_relation of this SearchResponseHits.  # noqa: E501
        :rtype: str
        """
        return self._total_relation
    @total_relation.setter
    def total_relation(self, total_relation):
        """Sets the total_relation of this SearchResponseHits.


        :param total_relation: The total_relation of this SearchResponseHits.  # noqa: E501
        :type total_relation: str
        """

        self._total_relation = total_relation
        

    @property
    def hits(self):
        """Gets the hits of this SearchResponseHits.  # noqa: E501


        :return: The hits of this SearchResponseHits.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._hits
    @hits.setter
    def hits(self, hits):
        """Sets the hits of this SearchResponseHits.


        :param hits: The hits of this SearchResponseHits.  # noqa: E501
        :type hits: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """

        self._hits = hits
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchResponseHits):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchResponseHits):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



from setuptools import setup, find_packages
from os import path

NAME = "manticoresearch-dev"
VERSION = "4.1.24030713"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
long_description = ""
with open(path.join(path.dirname(__file__), "README.md")) as f:
    for line in f:
      if '## Documentation for API Endpoints' in line:
        break
      long_description +=line
setup(
    name=NAME,
    version=VERSION,
    description="Python client for Manticore Search",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Manticore Software Ltd.",
    author_email="info@manticoresearch.com",
    url="",
    keywords=[ "full-text search","manticoresearch","search"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
	    project_urls={
        "Documentation": "https://github.com/manticoresoftware/manticoresearch-python/tree/master/docs",
        "Source Code": "https://github.com/manticoresoftware/manticoresearch-python",
        "Issue Tracker": "https://github.com/manticoresoftware/manticoresearch-python/issues",
    },
	classifiers=[
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Indexing/Search"
    ],
    license="MIT",
)



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class SearchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'str',
        'knn': 'SearchRequestKnn',
        'query': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'fulltext_filter': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'attr_filter': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'limit': 'int',
        'offset': 'int',
        'max_matches': 'int',
        'sort': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]',
        'aggs': '{str: (Aggregation,)}',
        'expressions': '{str: (str,)}',
        'highlight': 'Highlight',
        'source': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'options': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'profile': 'bool',
        'track_scores': 'bool',
        'query_vector': 'bool, date, datetime, dict, float, int, list, str, none_type',
        'doc_id': 'bool, date, datetime, dict, float, int, list, str, none_type',
        'k': 'bool, date, datetime, dict, float, int, list, str, none_type'
    }

    attribute_map = {
        'index': 'index',
        'knn': 'knn',
        'query': 'query',
        'fulltext_filter': 'fulltext_filter',
        'attr_filter': 'attr_filter',
        'limit': 'limit',
        'offset': 'offset',
        'max_matches': 'max_matches',
        'sort': 'sort',
        'aggs': 'aggs',
        'expressions': 'expressions',
        'highlight': 'highlight',
        'source': 'source',
        'options': 'options',
        'profile': 'profile',
        'track_scores': 'track_scores',
        'query_vector': 'query_vector',
        'doc_id': 'doc_id',
        'k': 'k'
    }

    def __init__(self, index="", knn=None, query=None, fulltext_filter=None, attr_filter=None, limit=None, offset=None, max_matches=None, sort=None, aggs=None, expressions=None, highlight=None, source=None, options=None, profile=None, track_scores=None, query_vector=None, doc_id=None, k=None, local_vars_configuration=None):  # noqa: E501
        """SearchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._knn = None
        self._query = None
        self._fulltext_filter = None
        self._attr_filter = None
        self._limit = None
        self._offset = None
        self._max_matches = None
        self._sort = None
        self._aggs = None
        self._expressions = None
        self._highlight = None
        self._source = None
        self._options = None
        self._profile = None
        self._track_scores = None
        self._query_vector = None
        self._doc_id = None
        self._k = None
        self.discriminator = None

        self.index = index
        if knn is not None:
            self.knn = knn
        if query is not None:
            self.query = query
        if fulltext_filter is not None:
            self.fulltext_filter = fulltext_filter
        if attr_filter is not None:
            self.attr_filter = attr_filter
        if limit is not None:
            self.limit = limit
        if offset is not None:
            self.offset = offset
        if max_matches is not None:
            self.max_matches = max_matches
        if sort is not None:
            self.sort = sort
        if aggs is not None:
            self.aggs = aggs
        if expressions is not None:
            self.expressions = expressions
        if highlight is not None:
            self.highlight = highlight
        if source is not None:
            self.source = source
        if options is not None:
            self.options = options
        if profile is not None:
            self.profile = profile
        if track_scores is not None:
            self.track_scores = track_scores
        self.query_vector = query_vector
        self.doc_id = doc_id
        self.k = k

    @property
    def index(self):
        """Gets the index of this SearchRequest.  # noqa: E501


        :return: The index of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._index
    @index.setter
    def index(self, index):
        """Sets the index of this SearchRequest.


        :param index: The index of this SearchRequest.  # noqa: E501
        :type index: str
        """
        if self.local_vars_configuration.client_side_validation and index is None:  # noqa: E501
            raise ValueError("Invalid value for `index`, must not be `None`")  # noqa: E501

        self._index = index
        

    @property
    def knn(self):
        """Gets the knn of this SearchRequest.  # noqa: E501


        :return: The knn of this SearchRequest.  # noqa: E501
        :rtype: SearchRequestKnn
        """
        return self._knn
    @knn.setter
    def knn(self, knn):
        """Sets the knn of this SearchRequest.


        :param knn: The knn of this SearchRequest.  # noqa: E501
        :type knn: SearchRequestKnn
        """

        self._knn = knn
        

    @property
    def query(self):
        """Gets the query of this SearchRequest.  # noqa: E501


        :return: The query of this SearchRequest.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._query
    @query.setter
    def query(self, query):
        """Sets the query of this SearchRequest.


        :param query: The query of this SearchRequest.  # noqa: E501
        :type query: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._query = query
        
        if self.fulltext_filter is not None:
        	self.fulltext_filter = None;
       	if self.attr_filter is not None:
        	self.attr_filter = None;

    @property
    def fulltext_filter(self):
        """Gets the fulltext_filter of this SearchRequest.  # noqa: E501


        :return: The fulltext_filter of this SearchRequest.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._fulltext_filter
    @fulltext_filter.setter
    def fulltext_filter(self, fulltext_filter):
        """Sets the fulltext_filter of this SearchRequest.


        :param fulltext_filter: The fulltext_filter of this SearchRequest.  # noqa: E501
        :type fulltext_filter: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._fulltext_filter = fulltext_filter
        

    @property
    def attr_filter(self):
        """Gets the attr_filter of this SearchRequest.  # noqa: E501


        :return: The attr_filter of this SearchRequest.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._attr_filter
    @attr_filter.setter
    def attr_filter(self, attr_filter):
        """Sets the attr_filter of this SearchRequest.


        :param attr_filter: The attr_filter of this SearchRequest.  # noqa: E501
        :type attr_filter: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._attr_filter = attr_filter
        

    @property
    def limit(self):
        """Gets the limit of this SearchRequest.  # noqa: E501


        :return: The limit of this SearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit
    @limit.setter
    def limit(self, limit):
        """Sets the limit of this SearchRequest.


        :param limit: The limit of this SearchRequest.  # noqa: E501
        :type limit: int
        """

        self._limit = limit
        

    @property
    def offset(self):
        """Gets the offset of this SearchRequest.  # noqa: E501


        :return: The offset of this SearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._offset
    @offset.setter
    def offset(self, offset):
        """Sets the offset of this SearchRequest.


        :param offset: The offset of this SearchRequest.  # noqa: E501
        :type offset: int
        """

        self._offset = offset
        

    @property
    def max_matches(self):
        """Gets the max_matches of this SearchRequest.  # noqa: E501


        :return: The max_matches of this SearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_matches
    @max_matches.setter
    def max_matches(self, max_matches):
        """Sets the max_matches of this SearchRequest.


        :param max_matches: The max_matches of this SearchRequest.  # noqa: E501
        :type max_matches: int
        """

        self._max_matches = max_matches
        

    @property
    def sort(self):
        """Gets the sort of this SearchRequest.  # noqa: E501


        :return: The sort of this SearchRequest.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._sort
    @sort.setter
    def sort(self, sort):
        """Sets the sort of this SearchRequest.


        :param sort: The sort of this SearchRequest.  # noqa: E501
        :type sort: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """

        self._sort = sort
        

    @property
    def aggs(self):
        """Gets the aggs of this SearchRequest.  # noqa: E501


        :return: The aggs of this SearchRequest.  # noqa: E501
        :rtype: {str: (Aggregation,)}
        """
        return self._aggs
    @aggs.setter
    def aggs(self, aggs):
        """Sets the aggs of this SearchRequest.


        :param aggs: The aggs of this SearchRequest.  # noqa: E501
        :type aggs: {str: (Aggregation,)}
        """

        self._aggs = aggs
        

    @property
    def expressions(self):
        """Gets the expressions of this SearchRequest.  # noqa: E501


        :return: The expressions of this SearchRequest.  # noqa: E501
        :rtype: {str: (str,)}
        """
        return self._expressions
    @expressions.setter
    def expressions(self, expressions):
        """Sets the expressions of this SearchRequest.


        :param expressions: The expressions of this SearchRequest.  # noqa: E501
        :type expressions: {str: (str,)}
        """

        self._expressions = expressions
        

    @property
    def highlight(self):
        """Gets the highlight of this SearchRequest.  # noqa: E501


        :return: The highlight of this SearchRequest.  # noqa: E501
        :rtype: Highlight
        """
        return self._highlight
    @highlight.setter
    def highlight(self, highlight):
        """Sets the highlight of this SearchRequest.


        :param highlight: The highlight of this SearchRequest.  # noqa: E501
        :type highlight: Highlight
        """

        self._highlight = highlight
        

    @property
    def source(self):
        """Gets the source of this SearchRequest.  # noqa: E501


        :return: The source of this SearchRequest.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._source
    @source.setter
    def source(self, source):
        """Sets the source of this SearchRequest.


        :param source: The source of this SearchRequest.  # noqa: E501
        :type source: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._source = source
        

    @property
    def options(self):
        """Gets the options of this SearchRequest.  # noqa: E501


        :return: The options of this SearchRequest.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._options
    @options.setter
    def options(self, options):
        """Sets the options of this SearchRequest.


        :param options: The options of this SearchRequest.  # noqa: E501
        :type options: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._options = options
        

    @property
    def profile(self):
        """Gets the profile of this SearchRequest.  # noqa: E501


        :return: The profile of this SearchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._profile
    @profile.setter
    def profile(self, profile):
        """Sets the profile of this SearchRequest.


        :param profile: The profile of this SearchRequest.  # noqa: E501
        :type profile: bool
        """

        self._profile = profile
        

    @property
    def track_scores(self):
        """Gets the track_scores of this SearchRequest.  # noqa: E501


        :return: The track_scores of this SearchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._track_scores
    @track_scores.setter
    def track_scores(self, track_scores):
        """Sets the track_scores of this SearchRequest.


        :param track_scores: The track_scores of this SearchRequest.  # noqa: E501
        :type track_scores: bool
        """

        self._track_scores = track_scores
        

    @property
    def query_vector(self):
        """Gets the query_vector of this SearchRequest.  # noqa: E501


        :return: The query_vector of this SearchRequest.  # noqa: E501
        :rtype: bool, date, datetime, dict, float, int, list, str, none_type
        """
        return self._query_vector
    @query_vector.setter
    def query_vector(self, query_vector):
        """Sets the query_vector of this SearchRequest.


        :param query_vector: The query_vector of this SearchRequest.  # noqa: E501
        :type query_vector: bool, date, datetime, dict, float, int, list, str, none_type
        """

        self._query_vector = query_vector
        

    @property
    def doc_id(self):
        """Gets the doc_id of this SearchRequest.  # noqa: E501


        :return: The doc_id of this SearchRequest.  # noqa: E501
        :rtype: bool, date, datetime, dict, float, int, list, str, none_type
        """
        return self._doc_id
    @doc_id.setter
    def doc_id(self, doc_id):
        """Sets the doc_id of this SearchRequest.


        :param doc_id: The doc_id of this SearchRequest.  # noqa: E501
        :type doc_id: bool, date, datetime, dict, float, int, list, str, none_type
        """

        self._doc_id = doc_id
        

    @property
    def k(self):
        """Gets the k of this SearchRequest.  # noqa: E501


        :return: The k of this SearchRequest.  # noqa: E501
        :rtype: bool, date, datetime, dict, float, int, list, str, none_type
        """
        return self._k
    @k.setter
    def k(self, k):
        """Sets the k of this SearchRequest.


        :param k: The k of this SearchRequest.  # noqa: E501
        :type k: bool, date, datetime, dict, float, int, list, str, none_type
        """

        self._k = k
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value


        result['_source'] = result['source']
        del result['source']
        if result['aggs'] is not None:
        	for k,v in result['aggs'].items():
        		if v['sort'] is None:
        			result['aggs'][k]['sort'] = []
        if result['highlight'] is not None:
	        if result['highlight']['fields'] is None: 	
	            result['highlight']['fields'] = result['highlight']['fieldnames']
	        result['highlight']['fieldnames'] = None
	        result['highlight'] = {k:v for k,v in result['highlight'].items() if v is not None}
        
        if result['fulltext_filter'] is not None or result['attr_filter'] is not None:
            result['query'] = {}
        if result['fulltext_filter'] is not None:
            for k,v in result['fulltext_filter'].items():
                result['query'][k] = v
            del result['fulltext_filter']
        if result['attr_filter'] is not None:
            for k,v in result['attr_filter'].items():
                result['query'][k] = v
            del result['attr_filter']


        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchRequest):
            return True

        return self.to_dict() != other.to_dict()
